@@ -10,7 +10,7 @@ LIST_VIEW = """
 @never_cache
 @renderer_classes([SwaggerUIRenderer, OpenAPIRenderer])
 @permission_classes((AllowAny, IsAuthenticated))
-def %(lower_model)s_list(request):
+def %(lower_model)_list(request):
 
     %(lower_model) =  %(model).objects.all()
     tmpJson = serializers.serialize("json", %(lower_model))
@@ -25,7 +25,7 @@ DETAILS_VIEW = """
 @never_cache
 @renderer_classes([SwaggerUIRenderer, OpenAPIRenderer])
 @permission_classes((AllowAny, IsAuthenticated))
-def %(lower_model)s_details(request, id):
+def %(lower_model)_details(request, id):
 
     %(lower_model) = %(model).objects.filter(pk=id) 
     tmpJson = serializers.serialize("json", %(lower_model))
@@ -41,7 +41,7 @@ DELETE_VIEW = """
 @never_cache
 @renderer_classes([SwaggerUIRenderer, OpenAPIRenderer])
 @permission_classes((AllowAny, IsAuthenticated))
-def %(lower_model)s_delete(request, id):
+def %(lower_model)_delete(request, id):
 
     item = %(model).objects.get(pk=id)
     item.delete()
@@ -59,7 +59,7 @@ CREATE_VIEW="""
 @never_cache
 @renderer_classes([SwaggerUIRenderer, OpenAPIRenderer])
 @permission_classes((AllowAny, IsAuthenticated))
-def %(lower_model)s_new(request):
+def %(lower_model)_new(request):
     fields = request.POST.get('fields')
 
     %(lower_model) = %(model)()
@@ -80,7 +80,7 @@ EDIT_VIEW="""
 @never_cache
 @renderer_classes([SwaggerUIRenderer, OpenAPIRenderer])
 @permission_classes((AllowAny, IsAuthenticated))
-def %(lower_model)s_edit(request):
+def %(lower_model)_edit(request):
     '''
     descriptions
     '''
